exceptiontools.MeasureContiguityError
=====================================

.. abjad-lineage:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError

.. autoclass:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MeasureContiguityError.MeasureContiguityError.__unicode__
   :noindex:
